@@ -1,30 +1,15 @@
 ;;; -*- Mode: Emacs-Lisp -*-
 
 ;;; ilisp-def.el --
-
-;;; This file is part of ILISP.
-;;; Version: 5.10.1
-;;;
-;;; Copyright (C) 1990, 1991, 1992, 1993 Chris McConnell
-;;;               1993, 1994 Ivan Vasquez
-;;;               1994, 1995, 1996 Marco Antoniotti and Rick Busdiecker
-;;;               1996-2000 Marco Antoniotti and Rick Campbell
-;;;
-;;; Other authors' names for which this Copyright notice also holds
-;;; may appear later in this file.
-;;;
-;;; Send mail to 'majordomo@cons.org' to be included in the
-;;; ILISP mailing list. 'ilisp@cons.org' is the general ILISP
-;;; mailing list were bugs and improvements are discussed.
-;;;
-;;; ILISP is freely redistributable under the terms found in the file
-;;; COPYING.
-
-
-
-;;;
 ;;; ILISP defvar's
 ;;;
+;;; This file is part of ILISP.
+;;; Please refer to the file COPYING for copyrights and licensing
+;;; information.
+;;; Please refer to the file ACKNOWLEGDEMENTS for an (incomplete) list
+;;; of present and past contributors.
+;;;
+;;; $Id: ilisp-def.el,v 1.13 2001/06/06 12:09:23 amoroso Exp $
 
 ;;;%Variables
 ;;;%%Deflocal
@@ -152,9 +137,12 @@ bol-ilisp skips them.")
 (defvar ilisp-mode-hook '()
   "Hook for customizing ilisp mode.")
 
-(deflocal ilisp-init-hook nil
+(defvar ilisp-init-hook nil
   "Hook of functions to call on first prompt in inferior LISP.")
 
+(deflocal ilisp-init-hook-local nil
+  "Local Hook of functions to call on first prompt in inferior LISP.")
+
 ;;;%%Advanced customization
 ;;;%%%Commands
 (deflocal ilisp-reset nil
@@ -164,11 +152,20 @@ bol-ilisp skips them.")
   "Format string for loading BINARY if possible otherwise loading FILE.
 If you can't load either, return NIL.")
 
-(deflocal ilisp-package-regexp nil
+(deflocal ilisp-hash-form-regexp nil
   "Regular expression for finding a package specification in a buffer.
 The entire sexp starting with this pattern will be passed to
 ilisp-package-command to find the package.")
 
+(deflocal ilisp-in-package-command-string nil
+  "Regular expression for finding a command that makes some package active.")
+
+(deflocal ilisp-defpackage-command-string nil
+  "Regular expression for finding a command that defines a package.")
+
+(deflocal ilisp-package-separator-regexp nil
+  "Regular expression that matches the package separator.")
+
 (deflocal ilisp-package-command nil
   "Format string to find the package given PACKAGE.")
 
@@ -190,14 +187,23 @@ ilisp-package-command to find the package.")
 (deflocal ilisp-block-command nil
   "Format string for grouping FORMS into one.")
 
+(deflocal ilisp-no-package-in-core-regexp nil
+  "Regexp that matches to ilisp-package-block-command's result in a
+case when the package was not found in core.  Remember to set
+`ilisp-fallback-package' too.")
+
+(deflocal ilisp-fallback-package nil
+  "Package name to be used when the buffer's real package cannot be found
+from the core.")
+
 (deflocal ilisp-eval-command nil
-  "Format string for evaluating FORM in PACKAGE from FILE.")
+  "Format string for evaluating FORM in PACKAGE from FILE at LINE.")
 
 (deflocal ilisp-defvar-regexp nil
   "Regular expression for identifying a defvar form.")
 
 (deflocal ilisp-defvar-command nil
-  "Format string for re-evaluating DEFVAR in PACKAGE from FILE.")
+  "Format string for re-evaluating DEFVAR in PACKAGE from FILE at LINE.")
 
 (deflocal ilisp-describe-command nil
   "Format string for describing FORM in PACKAGE.")
@@ -264,6 +270,9 @@ determined at initilization time.")
 (deflocal ilisp-compile-file-command nil
   "Format string for compiling a file in LISP given FILE and EXTENSION.")
 
+(deflocal ilisp-print-info-message-command nil
+  "Format string for printing argument list information etc. given a STRING.")
+
 ;;;%%%%Source
 (deflocal ilisp-source-types nil
   "Alist of strings for source types.
@@ -325,7 +334,7 @@ compile-file-lisp. Used by these commands to determine defaults.")
   "Non-nil if epoch is running.")
 
 (defvar ilisp-*version*
-  "5.10.1" ;; ILISP-VERSION marker
+  "5.11.1" ;; ILISP-VERSION marker
   "ILISP version.")
 
 (defvar ilisp-*directory* nil "The directory that ilisp is found in.")
@@ -470,7 +479,7 @@ the next one.")
 
 (defvar ilisp-*arglist-message-lisp-space-p* t
   "If T display the arglist or value of a function/symbol after a #\\Space.
-Set to t if you want the arglist or value of a function/symbol
+Set to 'all if you want the arglist or value of a function/symbol
 to be printed.")
 
 (defvar ilisp-*arglist-message-switch-back-p* nil
@@ -488,6 +497,10 @@ will not have any effect! This effectively means, that this variable
 must be set here. It relies on ilisp-*use-frame-for-output*, too.
 Only if both are t the output will be sent to a frame.")
 
+(defvar ilisp-*enable-ilisp-special-frame-p* nil
+  "If T, the ILISP inferior lisp buffer-name will be in
+special-display-buffer-names; therefore the lisp-interaction buffer
+will be in a 'special' seperate frame.")
 
 (defvar ilisp-*enable-imenu-p* t
   "Enables/disables loading/use of IMENU.
