@@ -1,29 +1,15 @@
 ;;; -*- Mode: Emacs-Lisp -*-
 
 ;;; ilisp-hi.el --
-
-;;; This file is part of ILISP.
-;;; Version: 5.10.1
-;;;
-;;; Copyright (C) 1990, 1991, 1992, 1993 Chris McConnell
-;;;               1993, 1994 Ivan Vasquez
-;;;               1994, 1995, 1996 Marco Antoniotti and Rick Busdiecker
-;;;               1996-2000 Marco Antoniotti and Rick Campbell
-;;;
-;;; Other authors' names for which this Copyright notice also holds
-;;; may appear later in this file.
-;;;
-;;; Send mail to 'majordomo@cons.org' to be included in the
-;;; ILISP mailing list. 'ilisp@cons.org' is the general ILISP
-;;; mailing list were bugs and improvements are discussed.
-;;;
-;;; ILISP is freely redistributable under the terms found in the file
-;;; COPYING.
-
-
-;;;
 ;;; ILISP high level interface functions Lisp <-> Emacs
 ;;;
+;;; This file is part of ILISP.
+;;; Please refer to the file COPYING for copyrights and licensing
+;;; information.
+;;; Please refer to the file ACKNOWLEGDEMENTS for an (incomplete) list
+;;; of present and past contributors.
+;;;
+;;; $Id: ilisp-hi.el,v 1.11 2001/05/12 22:10:53 marcoxa Exp $
 
 ;;;%Eval/compile
 (defun lisp-send-region (start end switch message status format
@@ -53,7 +39,12 @@ a message to let the user know what is going on."
 		   (if (= sexp 1)
 		       string
 		       (format (ilisp-value 'ilisp-block-command) string)))
-		  (lisp-buffer-package) (buffer-file-name)))
+		  (lisp-buffer-package)
+		  (buffer-file-name) 
+		  (save-excursion	; start line
+		    (goto-char (min start end))
+		    (beginning-of-line)
+		    (1+ (count-lines 1 (min start end))))))
     (let ((result 
 	   (ilisp-send
 	    string message status
@@ -161,10 +152,17 @@ With prefix, insert a call as well."
   (let ((old-point (point)))
     (mark-whole-buffer)
     (unwind-protect
-	 (compile-region-lisp (point) (mark) nil)
+      (let ((result
+              (compile-region-lisp (point) (mark) 'result
+                                   (format "Compiling Buffer %s"
+                                           (buffer-name (current-buffer))))))
+        (lisp-display-output result))
       (goto-char old-point)
       (set-mark old-point)
-      (deactivate-mark)
+      (or (and (fboundp 'deactivate-mark)
+               (deactivate-mark))
+          (and (fboundp 'zmacs-deactivate-region)
+               (zmacs-deactivate-region)))
       ;; ... and go implicitly -> you see what's going on!
       (switch-to-lisp t))))
 
@@ -502,26 +500,29 @@ The default directory of the optional BUFFER is used is available.  If
 you are in an inferior LISP buffer, set the default directory to the
 current directory of the LISP."
   (interactive)
-  (if (and (not buffer) (memq major-mode ilisp-modes))
-      (let ((dir
-	     (ilisp-send
-	      (ilisp-value 'ilisp-directory-command)
-	      (format "Getting LISP directory")
-	      'dir)))
+  (if (and (not buffer)
+	   (memq major-mode ilisp-modes)
+           (ilisp-value 'ilisp-directory-command))
+      (let ((dir (ilisp-send
+		  (ilisp-value 'ilisp-directory-command)
+		  (format "Getting LISP directory")
+		  'dir)))
 	(if (ilisp-value 'comint-errorp t)
 	    (progn
 	      (lisp-display-output dir)
 	      (error "Error getting directory"))
 	    (setq default-directory (read dir)
-		  lisp-prev-l/c-dir/file (cons default-direcotory nil))
+		  lisp-prev-l/c-dir/file (cons default-directory nil))
 	    (message "Default directory is %s" default-directory)))
-      (let ((directory (save-excursion
-			 (set-buffer (or buffer (current-buffer)))
-			 default-directory)))
-	(ilisp-send 
+      (let ((directory
+	     (expand-file-name (save-excursion
+				 (set-buffer (or buffer (current-buffer)))
+				 default-directory))))
+	(ilisp-send
 	 (format (ilisp-value 'ilisp-set-directory-command) directory)
 	 (format "Set %s's directory to %s" 
-		 (buffer-name (ilisp-buffer)) directory)
+		 (buffer-name (ilisp-buffer))
+		 directory)
 	 'dir
 	 ;; (if lisp-wait-p nil 'dispatch)
 	 ;; The above line might cause problems with Lispworks.
@@ -543,41 +544,41 @@ current directory of the LISP."
 	 (binary (lisp-file-extension file-name extension)))
     (save-excursion
       (set-buffer (ilisp-buffer))
-      (if (not (eq comint-send-queue comint-end-queue))
-	  (if (y-or-n-p "Abort commands before loading? ")
-	      (abort-commands-lisp)
-	      (message "Waiting for commands to finish")
-	      (while (not (eq comint-send-queue comint-end-queue))
-		(accept-process-output)
-		(sit-for 0))))
-      (if (and (car (comint-send-variables (car comint-send-queue)))
-	       (y-or-n-p "Interrupt top level? "))
-	  (let ((result (comint-send-results (car comint-send-queue))))
-	    (interrupt-subjob-ilisp)
-	    (while (not (cdr result))
-	      (accept-process-output)
-	      (sit-for 0)))))
-    (if (file-newer-than-file-p file-name binary)
-	(if (and (not ilisp-load-no-compile-query)
-		 extension (y-or-n-p "Compile first? "))
-	    ;; Load binary if just compiled
-	    (progn
-	      (message "")
-	      (compile-file-lisp file-name)
-	      (setq file-name binary)))
-	;; Load binary if it is current
-	(if (file-readable-p binary) (setq file-name binary)))
+      (unless (eq comint-send-queue comint-end-queue)
+        (if (y-or-n-p "Abort commands before loading? ")
+            (abort-commands-lisp)
+          (message "Waiting for commands to finish")
+          (while (not (eq comint-send-queue comint-end-queue))
+            (accept-process-output)
+            (sit-for 0))))
+      (when (and (car (comint-send-variables (car comint-send-queue)))
+                 (y-or-n-p "Interrupt top level? "))
+        (let ((result (comint-send-results (car comint-send-queue))))
+          (interrupt-subjob-ilisp)
+          (while (not (cdr result))
+            (accept-process-output)
+            (sit-for 0)))))
+    (unless (string= "system" (file-name-extension file-name))
+      (if (file-newer-than-file-p file-name binary)
+          (when (and (not ilisp-load-no-compile-query)
+                     extension (y-or-n-p "Compile first? "))
+            ;; Load binary if just compiled
+            (message "")
+            (compile-file-lisp file-name)
+            (setq file-name binary))
+        ;; Load binary if it is current
+        (when (file-readable-p binary)
+          (setq file-name binary))))
     (switch-to-lisp t t)
-
-	;; Ivan's hack for ange-ftp pathnames...
-	(let ((file-name
-		   (if (string-match "/.*?@.*:" file-name)
-			   (substring file-name (match-end 0))
-			   file-name)))
-	  (comint-sender
-	   (ilisp-process)
-	   (format (ilisp-value 'ilisp-load-command) file-name))
-	  (message "Loading %s" file-name))))
+    ;; Ivan's hack for ange-ftp pathnames...
+    (let ((file-name
+           (if (string-match "/.*?@.*:" file-name)
+               (substring file-name (match-end 0))
+             file-name)))
+      (comint-sender
+       (ilisp-process)
+       (format (ilisp-value 'ilisp-load-command) file-name))
+      (message "Loading %s" file-name))))
 
 
 
@@ -647,68 +648,64 @@ This function is intended to be bound to the #\\Space key so that,
 after being enabled it will display the arglist or value of a specific
 symbol after the symbol has been typed in followed by #\\Space."
   (interactive)
-  (when (and ilisp-*arglist-message-lisp-space-p* ; only if enabled
+  (when (and ilisp-*arglist-message-lisp-space-p* ; only if enabled and...
+             (ignore-errors             ; we can print info
+               (ilisp-value 'ilisp-print-info-message-command t))
 	     (ignore-errors
 	       (or (equal (ilisp-value 'ilisp-status) " :ready")
 		   (equal (ilisp-value 'ilisp-status) " :error")))
 	     (or (eql (current-buffer) (ilisp-buffer)) ; if in
 					; ILISP-Buffer, or else 
-		 ;; Only prints something if buffer-package already exists.
-		 (and (ignore-errors (lisp-buffer-package))
-                      (stringp buffer-package))))
+		 (ignore-errors (lisp-buffer-package))))
     (let* ((old-point (point))
 	   (last-char (progn (ignore-errors (backward-char))
 			     (unless (eql (point) old-point)
 			       (buffer-substring old-point (point)))))
 
 	   (string
-	    (buffer-substring old-point
-			      (progn
-				(goto-char old-point)
-				(ignore-errors (backward-sexp))
-				(point))))
+             (buffer-substring old-point
+                               (progn
+                                 (goto-char old-point)
+                                 (ignore-errors (backward-sexp))
+                                 (point))))
 	   (prefix-char 
-	    (let ((save (ignore-errors
-			  (goto-char old-point)
-			  (backward-sexp)
-			  (backward-char)
-			  (point))))
-	      (when save
-		(buffer-substring save (1+ save)))))
+             (let ((save (ignore-errors
+                           (goto-char old-point)
+                           (backward-sexp)
+                           (backward-char)
+                           (point))))
+               (when save
+                 (buffer-substring save (1+ save)))))
 	   (double-quote-pos (and string (string-match "\"" string)))
 	   (paren-pos (and string
 			   (string-match "(" string)))
 	   (ilisp-symbol-avec-package
-	    (unless (eql paren-pos 0)
-	      (lisp-string-to-symbol
-	       (if (and double-quote-pos (eql double-quote-pos 0) string)
-		   (substring string 1 -1)
-		   string))))
-	   (symbol (third ilisp-symbol-avec-package))
-	   )
+             (unless (eql paren-pos 0)
+               (lisp-string-to-symbol
+                (if (and double-quote-pos (eql double-quote-pos 0)
+                         string (ignore-errors (elt string 2)))
+                  (substring string 1 -1)
+                  string))))
+	   (symbol (lisp-symbol-name ilisp-symbol-avec-package))
+           (package (lisp-symbol-package ilisp-symbol-avec-package)))
+      (flet ((no-arglist-output-p ()
+               (or (and last-char 
+                        (or;; don't do silly things after comment character
+                          (equal last-char " ;")
+                          ;; do something only if directly after a sexp.
+                          (equal last-char " ")))
+                   (string-equal package "#+") (string-equal package "#-")
+                   double-quote-pos;; there is no output  for strings only.
+                   (not (and symbol (stringp symbol) (> (length symbol) 0)))
+                   (string-match "^\. " symbol))))
 
-      (goto-char old-point)
-
-      ;; symbol must be a string, no 'bracketed exps' are supported.
-
-      ;; ILISP must be 'ready' for this task, or in the debugger 'error'!
-
-      (unless (or (and last-char (equal last-char " ")) ; do something
-							; only if
-							; directly
-							; after a
-							; sexp.
-		  double-quote-pos	; there is no output  for
-					; strings only.
-		  (not (and symbol (stringp symbol) (> (length symbol) 0)))
-		   (string-match "^\. " symbol))
-        ;; only output for functions within brackets; otherwise there
-        ;; is too much lisp-traffic!
-        ;; or ilisp-*arglist-message-lisp-space-p* has
-        ;; to be set to 'all        
-        (when (or (equal prefix-char "(")
-                  (eql ilisp-*arglist-message-lisp-space-p* 'all))
-          (ilisp-arglist-message-lisp ilisp-symbol-avec-package)))))
+        (goto-char old-point)
+        (unless (no-arglist-output-p)
+          ;; only output for functions within brackets; too much lisp-traffic!
+          ;; or ilisp-*arglist-message-lisp-space-p* has to be set to 'all
+          (when (or (equal prefix-char "(")
+                    (eql ilisp-*arglist-message-lisp-space-p* 'all))
+            (ilisp-arglist-message-lisp ilisp-symbol-avec-package))))))
   (self-insert-command 1))
     
 
@@ -739,7 +736,6 @@ the symbol will be prompted for."
 		function t)
 	     function))))
 
-  ;; (message "ilisp-arglist-message-lisp: symbol = %s\n" symbol)
   (if (null symbol)
       (error "ilisp-arglist-message-lisp: null symbol")
     (let* ((arglist
@@ -752,8 +748,6 @@ the symbol will be prompted for."
 	     nil))
 	   (output arglist))
 
-      ;; (message ">>> '%s'\n>>> '%s'\n" arglist output)
-
       ;; Insert just the stuff after the double-quotes
       ;; but display everything the inferior lisp prints.
       (cond ((and (not (ilisp-value 'comint-errorp t))
